<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="单位类别">
              <el-select v-model="querys[0].value" style="width:100%" clearable>
                <el-option v-for="item in TypeList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="单位名称">
              <el-input v-model="querys[1].value" clearable placeholder="请输入单位名称" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="负责人姓名">
              <el-input v-model="querys[2].value" clearable placeholder="请输入负责人姓名" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <!-- <el-button icon="el-icon-plus" type="primary" @click="handleAdd"
          >新增</el-button
        >
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button
            slot="reference"
            :disabled="!multipleSelection.length"
            icon="el-icon-delete"
            type="danger"
            style="margin-left: 10px"
            >删除</el-button
          >
        </el-popconfirm> -->
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <!-- <el-table-column type="selection" width="55" /> -->
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column prop="unitName" label="单位名称" show-overflow-tooltip />
        <el-table-column prop="unitAddress" label="单位地址" show-overflow-tooltip />
        <el-table-column prop="name" label="负责人姓名" show-overflow-tooltip />
        <el-table-column prop="phone" label="负责人电话" show-overflow-tooltip />
        <!-- <el-table-column
          prop="type"
          label="单位类别"
          show-overflow-tooltip
        >
          <template slot-scope="scope">
            <el-tag v-if="scope.row.type === '1'">九小场所</el-tag>
            <el-tag v-else-if="scope.row.type === '2'">重点单位</el-tag>
            <el-tag v-else-if="scope.row.type === '3'">其它</el-tag>
          </template></el-table-column> -->
        <el-table-column prop="type" label="单位类别" show-overflow-tooltip />
        <!-- <el-table-column
          prop="fuelType"
          label="燃料种类"
          show-overflow-tooltip
        /> -->
        <el-table-column prop="employees" label="从业员工数量" show-overflow-tooltip />
        <el-table-column align="right" width="130px" label="操作" :index="999">
          <template slot-scope="scope">
            <el-button size="mini" type="primary" plain @click="detail(scope.row)">隐患历史记录
            </el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <el-dialog width="78%" title="当月申请单" :visible.sync="dialogVisible">
      <!-- <el-card style="cardPlan" class="box-card">
        <el-button size="mini" type="primary" plain @click="planDetails"
          >计划明细</el-button
        >
        <el-button size="mini" type="primary" plain @click="scenarioBreakdown"
          >方案明细</el-button
        >
        <el-button size="mini" type="primary" plain @click="hiddenRecords"
          >隐忠记录</el-button
        >
      </el-card> -->
      <el-table border class="application" size="mini" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" :data="gridData">
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column sortable prop="produceType" label="产生方式" show-overflow-tooltip />
        <el-table-column sortable prop="remindType" label="提醒方式" show-overflow-tooltip />
        <!-- <el-table-column
          sortable
          prop="remindRange"
          label="通知范围"
          show-overflow-tooltip
        /> -->
        <el-table-column sortable prop="workRemindTitle" label="工作提醒标题" show-overflow-tooltip />
        <el-table-column sortable prop="workRemindContent" label="工作提醒通知内容" show-overflow-tooltip width="180" />
        <el-table-column sortable prop="msgExigency" label="消息紧急程度" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-tag v-if="scope.row.msgExigency === '1'" type="success">普通
            </el-tag>
            <el-tag v-else-if="scope.row.msgExigency === '2'" type="warning">一般较急
            </el-tag>
            <el-tag v-else-if="scope.row.msgExigency === '3'" type="danger">紧急
            </el-tag>
          </template>
        </el-table-column>
        <el-table-column sortable prop="sendTime" label="发送时间" show-overflow-tooltip />
        <el-table-column sortable prop="receiveStatus" label="发送状态" show-overflow-tooltip />
      </el-table>
    </el-dialog>
    <SecurityFileFormDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import SecurityFileApi from '@/views/Manage/saftyDanger/api/SecurityFileApi'
import CmgtTSaftyWorkConfApi from '@/views/Manage/saftyDanger/api/CmgtTSaftyWorkConfApi'
import SecurityFileFormDialog from '@/views/Manage/saftyDanger/components/SecurityFileFormDialog'

export default {
  name: 'CmgtSaftyDangerUnitManage',
  components: {
    SecurityFileFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      dialogVisible: false,
      gridData: [],
      url: {
        delete: '/manager/cmgtSaftyDangerUnit/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'unit_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      sorter: [
        {
          direction: 'ASC',
          property: ''
        }
      ]
      // levels:[]
    }
  },
  created() {
    this.TypeList = dictUtils.getDictItemsFromCache('zhgl-dwlx')
    this.fuelTypeList = dictUtils.getDictItemsFromCache('rlzl')
    // this.remindTypeList = dictUtils.getDictItemsFromCache('yjtxfs')
    // this.remindRangeList = dictUtils.getDictItemsFromCache('tzfw')
    // console.log(this.produceTypeList)
  },
  mounted() {
  },
  methods: {
    //
    ActivateDisable() {
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      SecurityFileApi.loadCmgtSaftyTrainingPlan(this.queryParam).then(res => {
        const { total, rows } = res.data
        this.total = total
        this.tableData = rows
        this.tableData.forEach(item => {
          this.TypeList.forEach(val => {
            // console.log(val)
            if (item.type == val.value) {
              item.type = val.name
            }
          })
          this.fuelTypeList.forEach(val => {
            if (item.fuelType == val.value) {
              item.fuelType = val.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    //
    planDetails() {
    },
    // 详情
    detail(row) {
      // console.log(row)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    formartTyepName(row, column, cellValue, index) {
      var obj = this.types.find(function (item) {
        if (item.value === row.type) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.el-card {
  margin-bottom: 20px;
}
</style>
